==> library1.4.1.tar.bz2: library/vidano-search.php <==
<?php
///////////////////////////////////////////////////
//2010 (C)
//Карпухин Павел
///////////////////////////////////////////////////
require_once "utils/chlang_osn.php";

$title = $TEXT['menu-btn31-title'];

require_once "config.php";
require_once "utils/functions.php";
require_once "utils/top.php";

if($result2['administrator'] == 0) {puterror2($result2['skin'],$TEXT['error-loginform2']); require_once "utils/bottom.php"; exit();}

if(strlen($_GET['k'])>8) {puterror2($result2['skin'],$TEXT['error-paging1']); require_once "utils/bottom.php"; exit();}
$_GET['k'] = rep($_GET['k']);
if(empty($_GET['k'])) {$_GET['k']=0;}
$stop_r = $_GET['k'];
if($stop_r == 0) {$lim_ogr = "10";}
else {$lim_ogr = $stop_r.",10";}

$ktblvis = $stop_r+10;
$str = $ktblvis/10;
?>
<table align="center" border="0" cellpadding="0" cellspacing="0" width="90%">
<tr align="right">
<td><img alt="<?php echo $TEXT['book-nap-now']; ?>" src='skins/<?php echo $result2['skin']; ?>/mail-all.png' />&nbsp;<a class="bold_it" href="mail_all.php" title="<?php echo $TEXT['book-nap-now-tit']; ?>"><?php echo $TEXT['book-nap-now']; ?></a></td>
</tr>
</table>
<table align="center" border="0" cellpadding="3" cellspacing="0" width="90%">
<thead><tr class='tableheadercat'>
<td><?php echo $TEXT['book-sost']; ?></td>
<td><?php echo $TEXT['book-name']; ?></td>
<td><?php echo $TEXT['book-bibl']; ?></td>
<td><?php echo $TEXT['book-who-vid']; ?></td>
<td><?php echo $TEXT['book-data3']; ?></td>
<td><?php echo $TEXT['book-data4']; ?></td>
<td><?php echo $TEXT['book-zad']; ?></td>
</tr></thead>
<tbody id="tab" >
<?php
     $query_body = "SELECT 
     tbl_book.book_name,
     tbl_book.book_id,
     tbl_book.napominalka,
     YEAR(tbl_book.data_vidachi) AS data_vidachi_year,
     MONTH(tbl_book.data_vidachi) AS data_vidachi_month,
     DAY(tbl_book.data_vidachi) AS data_vidachi_day,
     YEAR(tbl_book.data_sdachi) AS data_sdachi_year,
     MONTH(tbl_book.data_sdachi) AS data_sdachi_month,
     DAY(tbl_book.data_sdachi) AS data_sdachi_day,
     tbl_book.user_id,
     tbl_biblioteka.name AS bibl_name,
     tbl_logins.familiya,
     tbl_logins.name,
     tbl_logins.otchestvo
     FROM tbl_book
     JOIN tbl_biblioteka ON tbl_book.bibl_id=tbl_biblioteka.bibl_id
     JOIN tbl_logins ON tbl_book.user_id=tbl_logins.login_id
     WHERE tbl_book.vidano ='1'
     ORDER BY tbl_book.data_sdachi, tbl_book.book_name
     LIMIT $lim_ogr ";
     $result_body = mysqli_query($dbcnx,$query_body);
     if(!$result_body) {puterror2($result2['skin'],$TEXT['error-tbl3']); require_once "utils/bottom.php"; exit();}
       $result_rows = mysqli_num_rows($result_body);
       if($result_rows > 0)
         {
          while($result_body_book= mysqli_fetch_array($result_body))
               {

               $query_zad = mysqli_query($dbcnx,"SELECT DATEDIFF(CURRENT_DATE(),data_sdachi) AS zad_date FROM tbl_book WHERE book_id = ".$result_body_book['book_id']."");
                $res_zad = mysqli_fetch_array($query_zad);

               $date_day = $result_body_book['data_sdachi_day'];
               $date_month = $result_body_book['data_sdachi_month'];
               $date_year = $result_body_book['data_sdachi_year'];
               $year = $TEXT['year2'];
               if($date_year == "0000" || $date_year == "1970") {$data_sd = "---";}
                else {$data_sd = (date("$date_day $month[$date_month] $date_year $year"));}

               $date_day2 = $result_body_book['data_vidachi_day'];
               $date_month2 = $result_body_book['data_vidachi_month'];
               $date_year2 = $result_body_book['data_vidachi_year'];
               if($date_year2 == "0000" || $date_year2 == "1970") {$data_vid = "---";}
                else {$data_vid = (date("$date_day2 $month[$date_month2] $date_year2 $year"));}

               if($res_zad['zad_date'] < 1)
               {
                $book_sost = "<img alt='ok' src='skins/".$result2['skin']."/active.png' />";
                $zad = $TEXT['book-zad-no'];
               }
                else
                {
                 if($result_body_book['napominalka'] == "0") {$book_sost = "<img alt='warning' src='skins/".$result2['skin']."/warn.png' />";}
                  else {$book_sost = "<img alt='warning' src='skins/".$result2['skin']."/warn-nap.png' />";}
                 $zad = $res_zad['zad_date']."&nbsp;".$TEXT['book-zad-days']."&nbsp;<a href=mail.php?book_id=".$result_body_book['book_id']." title='".$TEXT['log-mail']."'><img alt='mail' src='skins/".$result2['skin']."/mail.png' /></a>";
                }

               $bibl = $result_body_book['bibl_name'];
               $book_name = "<a href=info.php?book_id=".$result_body_book['book_id']." title='".$TEXT['aut-viewtit']."'>".rep_back($result_body_book['book_name'])."</a>";

               ?>
               <tr>
                <td><?php echo $book_sost; ?></td>
                <td class="informcntr"><?php echo $book_name; ?></td>
                <td><?php echo $bibl; ?></td>
                <td><?php echo $result_body_book['familiya']; ?> <?php echo $result_body_book['name']; ?> <?php echo $result_body_book['otchestvo']; ?></td>
                <td><?php echo $data_vid; ?></td>
                <td><?php echo $data_sd; ?></td>
                <td><?php echo $zad; ?></td>
               </tr>
               <?php
               }
         }
?>
</tbody>
</table>
     <?php
       $query_count = mysqli_query($dbcnx,"SELECT COUNT(book_id) AS c_book_id FROM tbl_book WHERE vidano ='1'");
	       $coun_rows = mysqli_fetch_array($query_count);
               $pag = $coun_rows['c_book_id']/10;
               if($pag<=1) {$pag = ceil($pag);}
                else
                {
                 ?>
                  <hr size="3" width="98%" />
                  <table align="center" border="0" cellpadding="0" cellspacing="0" width="60%" >
                   <tr align="center">
                    <td>
                <?php
                $pag=ceil($pag);
                $strn = $str-5;
                if($strn<1) {$strn=1;}
                $strk = $str+5;
                for($i=$strn; $i<=$pag; $i++)
                 {
                  if($i<=$strk)
                  {
                    if($i==$str)
                    {
                      $k = $i*10-10;
                      $kvis=$k+10;
                      $nvis=$k;
                      echo $pg = " <a class='zagolovok' href='vidano-search.php?k=".$k."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>".$i."</a>";
                    }
                    else
                    {
                    $k = $i*10-10;
                    $kvis=$k+10;
                    $nvis=$k;
                    echo $pg = " <a href='vidano-search.php?k=".$k."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>[".$i."]</a>";
                    }
                  }
                 }
                 ?>
                    <select name='k' onchange=window.location.href=this.options[this.selectedIndex].value;>
                    <?php
                    for($j=1; $j<=$pag; $j++)
                    {
                     $k = $j*10-10;
                     if($k == $_GET['k']) {echo "<option selected value=vidano-search.php?k=".$k.">".$j."</option>";}
                       else {echo "<option value=vidano-search.php?k=".$k.">".$j."</option>";}
                    }
                    ?>
                    </select>
                    </td>
                   </tr>
                  </table>
                 <?php
                }
  require_once "utils/bottom.php";
?>

==> library1.19.1.tar.bz2: library/vidano-search.php <==
<?php
///////////////////////////////////////////////////
//2010 (C)
//Карпухин Павел
///////////////////////////////////////////////////
require_once "utils/chlang_osn.php";

$title = $TEXT['menu-btn31-title'];

require_once "config.php";
require_once "utils/functions.php";
require_once "utils/top.php";

if($result2['administrator'] == 0) {puterror2($result2['skin'],$TEXT['error-loginform2']); require_once "utils/bottom.php"; exit();}

if(strlen($_GET['k'])>8) {puterror2($result2['skin'],$TEXT['error-paging1']); require_once "utils/bottom.php"; exit();}
$_GET['k'] = rep($_GET['k']);
if(empty($_GET['k'])) {$_GET['k']=0;}
$stop_r = $_GET['k'];
if($stop_r == 0) {$lim_ogr = "10";}
else {$lim_ogr = $stop_r.",10";}

$ktblvis = $stop_r+10;
$str = $ktblvis/10;
?>
<table align="center" border="0" cellpadding="0" cellspacing="0" width="90%">
<tr align="right">
<td><img alt="<?php echo $TEXT['book-nap-now']; ?>" src='skins/<?php echo $result2['skin']; ?>/mail-all.png' />&nbsp;<a class="bold_it" href="mail_all.php" title="<?php echo $TEXT['book-nap-now-tit']; ?>"><?php echo $TEXT['book-nap-now']; ?></a></td>
</tr>
</table>
<table align="center" border="0" cellpadding="3" cellspacing="0" width="90%">
<thead><tr class="tableheadercat">
<td><?php echo $TEXT['book-sost']; ?></td>
<td><?php echo $TEXT['book-name']; ?></td>
<td><?php echo $TEXT['book-bibl']; ?></td>
<td><?php echo $TEXT['book-who-vid']; ?></td>
<td><?php echo $TEXT['book-data3']; ?></td>
<td><?php echo $TEXT['book-data4']; ?></td>
<td><?php echo $TEXT['book-zad']; ?></td>
</tr></thead>
<tbody id="tab" >
<?php
     $query_body = "SELECT 
     tbl_book.data_sdachi,
     tbl_book.book_name,
     tbl_book.book_id,
     tbl_book.napominalka,
     YEAR(tbl_book.data_vidachi) AS data_vidachi_year,
     MONTH(tbl_book.data_vidachi) AS data_vidachi_month,
     DAY(tbl_book.data_vidachi) AS data_vidachi_day,
     YEAR(tbl_book.data_sdachi) AS data_sdachi_year,
     MONTH(tbl_book.data_sdachi) AS data_sdachi_month,
     DAY(tbl_book.data_sdachi) AS data_sdachi_day,
     tbl_book.user_id,
     tbl_biblioteka.name AS bibl_name,
     tbl_logins.familiya,
     tbl_logins.name,
     tbl_logins.otchestvo
     FROM tbl_book
     JOIN tbl_biblioteka ON tbl_book.bibl_id=tbl_biblioteka.bibl_id
     JOIN tbl_logins ON tbl_book.user_id=tbl_logins.login_id
     WHERE tbl_book.vidano ='1'
     ORDER BY tbl_book.data_sdachi, tbl_book.book_name
     LIMIT $lim_ogr ";
     $result_body = mysqli_query($dbcnx,$query_body);
     if(!$result_body) {puterror2($result2['skin'],$TEXT['error-tbl3']); require_once "utils/bottom.php"; exit();}
       $result_rows = mysqli_num_rows($result_body);
       if($result_rows > 0)
         {
          while($result_body_book= mysqli_fetch_array($result_body))
               {

               $query_zad = mysqli_query($dbcnx,"SELECT DATEDIFF(CURRENT_DATE(),data_sdachi) AS zad_date FROM tbl_book WHERE book_id = ".$result_body_book['book_id']."");
                $res_zad = mysqli_fetch_array($query_zad);

               $date_day = $result_body_book['data_sdachi_day'];
               $date_month = $result_body_book['data_sdachi_month'];
               $date_year = $result_body_book['data_sdachi_year'];
               $year = $TEXT['year2'];
               if($date_year == "0000" || $date_year == "1970") {$data_sd = "---";}
                else {$data_sd = (date("$date_day $month[$date_month] $date_year $year"));}

               $date_day2 = $result_body_book['data_vidachi_day'];
               $date_month2 = $result_body_book['data_vidachi_month'];
               $date_year2 = $result_body_book['data_vidachi_year'];
               if($date_year2 == "0000" || $date_year2 == "1970") {$data_vid = "---";}
                else {$data_vid = (date("$date_day2 $month[$date_month2] $date_year2 $year"));}

               if($res_zad['zad_date'] < 1)
               {
                $book_sost = "<img alt='ok' src='skins/".$result2['skin']."/active.png' />";
                $zad = $TEXT['book-zad-no'];
               }
                else
                {
                 if($result_body_book['napominalka'] == "0") {$book_sost = "<img alt='warning' src='skins/".$result2['skin']."/warn.png' />";}
                  else {$book_sost = "<img alt='warning' src='skins/".$result2['skin']."/warn-nap.png' />";}
                 $zad = $res_zad['zad_date']."&nbsp;".$TEXT['book-zad-days']."&nbsp;<a href='mail.php?book_id=".$result_body_book['book_id']."' title='".$TEXT['log-mail']."'><img alt='mail' src='skins/".$result2['skin']."/mail.png' /></a>";
                }

               $bibl = $result_body_book['bibl_name'];
               $book_name = "<a href='info.php?book_id=".$result_body_book['book_id']."' title='".$TEXT['aut-viewtit']."'>".rep_back($result_body_book['book_name'])."</a>";

               ?>
               <tr>
                <td><?php echo $book_sost; ?></td>
                <td class="informcntr"><?php echo $book_name; ?></td>
                <td><?php echo $bibl; ?></td>
                <td><?php echo $result_body_book['familiya']; ?> <?php echo $result_body_book['name']; ?> <?php echo $result_body_book['otchestvo']; ?></td>
                <td><?php echo $data_vid; ?></td>
                <td><?php echo $data_sd; ?></td>
                <td><?php echo $zad; ?></td>
               </tr>
               <?php
               }
         }
?>
</tbody>
</table>
     <?php
       $query_count = mysqli_query($dbcnx,"SELECT COUNT(book_id) AS c_book_id FROM tbl_book WHERE vidano ='1'");
	       $coun_rows = mysqli_fetch_array($query_count);
               $pag = $coun_rows['c_book_id']/10;
               if($pag<=1) {$pag = ceil($pag);}
                else
                {
                 ?>
                  <hr size="3" width="98%" />
                  <table align="center" border="0" cellpadding="0" cellspacing="0" width="60%" >
                   <tr align="center">
                    <td>
                <?php
                $pag=ceil($pag);
                $strn = $str-5;
                if($strn<1) {$strn=1;}
                $strk = $str+5;
                for($i=$strn; $i<=$pag; $i++)
                 {
                  if($i<=$strk)
                  {
                    if($i==$str)
                    {
                      $k = $i*10-10;
                      $kvis=$k+10;
                      $nvis=$k;
                      echo $pg = " <a class='zagolovok' href='vidano-search.php?k=".$k."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>".$i."</a>";
                    }
                    else
                    {
                    $k = $i*10-10;
                    $kvis=$k+10;
                    $nvis=$k;
                    echo $pg = " <a href='vidano-search.php?k=".$k."' title='".$TEXT['tbl-details4'].$nvis.$TEXT['tbl-details3'].$kvis."'>[".$i."]</a>";
                    }
                  }
                 }
                 ?>
                    <select name='k' onchange=window.location.href=this.options[this.selectedIndex].value;>
                    <?php
                    for($j=1; $j<=$pag; $j++)
                    {
                     $k = $j*10-10;
                     if($k == $_GET['k']) {echo "<option selected value=vidano-search.php?k=".$k.">".$j."</option>";}
                       else {echo "<option value=vidano-search.php?k=".$k.">".$j."</option>";}
                    }
                    ?>
                    </select>
                    </td>
                   </tr>
                  </table>
                 <?php
                }
  require_once "utils/bottom.php";
?>
